Debugger/StartDialog.py

changeset 112
16893e193e9d
parent 96
9624a110667d
child 564
b3d966393ba9
child 792
a13346916170
--- a/Debugger/StartDialog.py	Sat Feb 13 13:00:30 2010 +0000
+++ b/Debugger/StartDialog.py	Sat Feb 13 17:07:34 2010 +0000
@@ -100,7 +100,11 @@
             self.ui.forkModeCheckBox.setChecked(autoFork)
             self.ui.forkChildCheckBox.setChecked(forkChild)
         
-        if type == 3:   # start coverage or profile dialog
+        if type == 1:       # start run dialog
+            self.ui.forkModeCheckBox.setChecked(autoFork)
+            self.ui.forkChildCheckBox.setChecked(forkChild)
+        
+        if type == 3:       # start coverage or profile dialog
             self.ui.eraseCheckBox.setChecked(True)
         
         self.__clearHistoryLists = False
@@ -163,6 +167,18 @@
                     self.ui.forkModeCheckBox.isChecked(), 
                     self.ui.forkChildCheckBox.isChecked())
         
+    def getRunData(self):
+        """
+        Public method to retrieve the debug related data entered into this dialog.
+        
+        @return a tuple of a flag indicating, that the debugger should fork automatically
+            (boolean) and a flag indicating, that the debugger should debug the child 
+            process after forking automatically (boolean)
+        """
+        if self.type == 1:
+            return (self.ui.forkModeCheckBox.isChecked(), 
+                    self.ui.forkChildCheckBox.isChecked())
+        
     def getCoverageData(self):
         """
         Public method to retrieve the coverage related data entered into this dialog.

eric ide

mercurial